      subroutine optmean
     & (ncl, rlambda, ccomp3, thknot, p14, tlty, tlai, 
     & rleff, tleff, rneff, rty)
c
c  the mean values of optical parameters    A. Kuusk 23.09.1995
c
c  Input:
c    & (ncl, rlambda, thknot, p14, tlty, tlai, utot
c    
c  Output:
c    tleff, rleff, rneff, rty, rleff, tleff
c
c  utot - total LAI (leaves + branches + stems)
c  rleff - total efffective leaf reflectance
c  tleff - total efffective leaf transmittance
c
      include 'par.h'
      include 'stands.h'
      include 'spectra.h'
      dimension ccomp3(nclmax, ncomp0)
      dimension thknot(nknots), p14(nknots)
      dimension acoef1(nspchnl, ncomp0), acoef2(nspchnl, ncomp0)
      dimension acoef3(nclmax, nspchnl, ncomp0)
      common /pidr/ pi, dr
      common /spect3/ acoef1, acoef2, acoef3
c
      jwl   = nint((rlambda - (400.d0 - wlstep))/wlstep)
      rind = refr(jwl)
c                                  ! Leaf reflectance and transmittance
      do jcl = 1, ncl
        dkl = 0.d0
        do jc = 1, ncomp3(jcl)
          dkl = dkl + ccomp3(jcl, jc)*acoef3(jcl, jwl, jc)
        enddo
        slw = slwcl(jcl)
        vai = vaicl(jcl)
        if (lmod3(jcl) .eq. 'prospect') then
          dkl = dkl/vai*slw*1.d-6
          call prospect(rind, dkl, vai, refl, tran)
        else if (lmod3(jcl) .eq. 'liberty') then
          rinf = -99.d0
          dcell0 = 80.d0
          asp = acl(jcl)
          coeff = dkl*dcl(jcl)/dcell0*slw*1.d-6/vai
          call liberty
     &         (thknot, p14, rind, coeff, vai, asp, rinf, refl, tran)
          if (refl .eq. rinf .or. rinf .lt. 0d0) then
            write (0, '(/a/a, f6.1, f10.4 /)') 'LIBERTY:',
     &        'Cannot calculate leaf reflectance, lambda, r_leaf = ', 
     &        rlambda, refl
            stop
          endif
        else
          print *, 'ERR: No leaf optics model'
          stop
        endif 
c     
        rnlfj      = rnlfc(jcl)*rind
        if (rnlfj .lt. 1.d0) rnlfj = 1.d0
        rnlf(jcl)   = rnlfj
        rspj = ((1.d0 - rnlfj)/(1.d0 + rnlfj))**2
        rlfcl(jcl) = refl - rspj
        tlfcl(jcl) = tran
        rbrnc(jcl) = brrarr(jcl, jwl)
        rtrnk(jcl) = trrarr(jcl, jwl)
      enddo 
c
      sum2   = 0.d0
      do j = 1, ncl
        stdj    = stdns(j)
        htrj    = htr(j)
        hcrj    = hc1(j) + hc2(j)
        cli     = stdj*dbh(j)*.5d0*(htrj - hcrj)
        sum2    = sum2 + cli*rtrnk(j)
      enddo
      rty    = 0.d0
      if (tlty .ne. 0.d0) rty = sum2*pi/tlty
c
      sumrl  = 0.d0
      sumtl  = 0.d0
      sumrty = 0.d0
      sumn   = 0.d0
      sumlai = 0.d0
c
      do jcl = 1, ncl
        rnlfj        = rnlf(jcl)
        rlaief       = rlaicl(jcl)*clmpsh(jcl)
        baiclj       = baicl(jcl)
        tlaij        = rlaief + baiclj
        rdlf         = (rlaief*rlfcl(jcl) + baiclj*rbrnc(jcl))/tlaij
        rrs(jcl, jwl) = rdlf
        tyclj        = tycl(jcl)
c
        tdif        = rlaief*tlfcl(jcl)/tlaij
        ttt(jcl, jwl) = tdif
c
        sumrl    = sumrl + rdlf*tlaij
        sumtl    = sumtl + tdif*tlaij
        sumn     = sumn + rlaief*rnlfj
        sumrty   = sumrty + rtrnk(jcl)*tyclj
        sumlai   = sumlai + tlaij
      enddo
c
      rlmean = sumrl/sumlai
      tlmean = sumtl/sumlai
      rtymn  = sumrty/tlty
      r12   = (rlmean*sumlai + rtymn*tlty)/(sumlai + tlty)
      tleff = tlmean*sumlai/(sumlai + tlty)
      rneff = 1.d0
      if (tlai .ne. 0.d0) rneff = sumn/sumlai
      rleff = r12 + ((rneff - 1.d0)/(rneff + 1.d0))**2
c
      return
      end
*
************************************************************************
*
